@@ -34,9 +34,6 @@ def service(context_name: str = DEFAULT) -> Callable[[Type[T]], Type[T]]:
         if not services_dict.get(context_name):
             services_dict[context_name] = {}
         class_base: Type[T] = cls.__bases__[0]  # Interface
-        # Check if service already is mapped for context
-        if services_dict.get(context_name).get(class_base):
-            raise ValueError(f"Service {class_base} already mapped for context {context_name}")
         services_dict[context_name][class_base] = cls
         services.add(class_base)
         return cls
